package temperature

import (
	"fmt"
	"log"
	"os"

	"github.com/go-flucky/flucky/pkg/cli"
	"github.com/go-flucky/flucky/pkg/config"
	"github.com/go-flucky/flucky/pkg/logfile"
	"github.com/go-flucky/flucky/pkg/sensor"
	"github.com/spf13/cobra"
)

var compression bool
var logs bool

var readTemperatureCmd = &cobra.Command{
	Use:     "read",
	Short:   "read temperature from sensor",
	Example: fmt.Sprintf("flucky temperature read\nflucky temperature read outdoor"),
	Run: func(cmd *cobra.Command, args []string) {

		// read configuration
		cnf, err := config.Read(configFile)
		if err != nil {
			log.Fatalln(err)
		}

		// fetch all temperature sensors or sensors by args
		temperatureSensors := make([]sensor.TemperatureSensor, 0)
		if len(args) == 0 {
			temperatureSensors = cnf.GetTemperatureSensors(config.ENABLED)
		} else {
			temperatureSensors = cnf.GetTemperatureSensorsByName(args)
		}

		// read temperature from sensors
		temperatures, err := sensor.ReadTemperatures(temperatureSensors)
		if err != nil {
			log.Fatalln(err)
		}

		// print temperatures on stdout
		cli.PrintTemperatures(temperatures, cnf, os.Stdout)

		if logs {
			err := logfile.WriteTemperatures(temperatures, cnf.Device.TemperatureLogfile, compression)
			if err != nil {
				log.Fatalln(err)
			}
		}
	},
}

func init() {
	temperatureCmd.AddCommand(readTemperatureCmd)
	readTemperatureCmd.Flags().BoolVarP(&logs, "logs", "l", true, "Log temperature")
	readTemperatureCmd.Flags().BoolVarP(&compression, "compression", "c", true, "Compress measured with logged temperatures")
}
